xtea

package
v0.1.19 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 9, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DebugBorder

func DebugBorder(content string, borderColor color.Color) string

DebugBorder wraps content with a colored border for debugging layout issues.

func PadLinesToWidth

func PadLinesToWidth(sections []string, width int)

PadLinesToWidth pads each line in sections to fill the given width.

Types

This section is empty.

Jump to