Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DebugBorder ¶
DebugBorder wraps content with a colored border for debugging layout issues.
func PadLinesToWidth ¶
PadLinesToWidth pads each line in sections to fill the given width.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.